==> haskell-yesod-auth-1.6.7-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-auth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-auth
version: 1.6.7
id: yesod-auth-1.6.7-56lcxxwJCfWEVFyMpPtQkv
key: yesod-auth-1.6.7-56lcxxwJCfWEVFyMpPtQkv
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman, Patrick Brisbin
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Authentication for Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-auth>
category: Web, Yesod
abi: 43b3b7ccea19f8d01b7d032688fe225e
exposed: True
exposed-modules:
    Yesod.Auth Yesod.Auth.BrowserId Yesod.Auth.Dummy Yesod.Auth.Email
    Yesod.Auth.GoogleEmail2 Yesod.Auth.Hardcoded Yesod.Auth.Message
    Yesod.Auth.OpenId Yesod.Auth.Rpxnow Yesod.Auth.Util.PasswordStore
hidden-modules: Yesod.Auth.Routes
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-auth-1.6.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-auth-1.6.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-auth-1.6.7
hs-libraries: HSyesod-auth-1.6.7-56lcxxwJCfWEVFyMpPtQkv
depends:
    aeson-1.4.4.0-8EzwlpxsJYiJGXz8JVXZ1i
    authenticate-1.3.4-KS6D20FoM1cKmcUG5NvXch base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    base64-bytestring-1.0.0.2-Exy4D7U0AzaE8TUydrgSTP binary-0.8.6.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-html-0.9.1.1-6PAyIvh6hy6Ilt6w0CbPFV
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    conduit-1.3.1.1-7rGn2miUuc0IzsMPA6GM7m
    conduit-extra-1.3.2-2xarBShtmoTHDN9knVQRhr containers-0.6.0.1
    cryptonite-0.26-5pCtI3fv84M4lNt7lObUcf
    data-default-0.7.1.1-GQk9Hqcpzml6dpaWfistUm
    email-validate-2.3.2.11-6SEgdOWqAG9BVcC4rU1zb9
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
    http-client-0.6.4-LC2XTclyTBtLSxSxXQXavF
    http-client-tls-0.3.5.3-JMPgLQAo3UE13O2HNdBa5j
    http-conduit-2.3.7.1-IliglbYlp2a1JIiNe3n5cf
    http-types-0.12.3-4KWln6jzZFqKSBXaEIoMvB
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    nonce-1.0.7-LFt1Yh6hHnS1mDFUIyY8HS
    persistent-2.9.2-Ij4kk7kwmQNISyGnaOvmpB
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    shakespeare-2.0.20-293yKPRYbgbBORKgFSWUOa template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    unliftio-0.2.11-HfZ36uDuQPe4HzZMREy7XZ
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-8dby3miKFglJ7BLkdgbDGw
    wai-3.2.2.1-6ydTyP8W1GG9uWvckOIvF6
    yesod-core-1.6.14-EuRsuwX5KCIHFIhzqQhAqC
    yesod-form-1.6.5-Io3LuZDwHEp8g97JLgrKd2
    yesod-persistent-1.6.0.2-ApVJUgQLkm3CzC3Mgc6QBT
haddock-interfaces: /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
haddock-html: /usr/share/doc/haskell-yesod-auth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-auth-1.6.7-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-auth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-auth
version: 1.6.7
id: yesod-auth-1.6.7-4gBMbGeaBFYHehqr8yISWf
key: yesod-auth-1.6.7-4gBMbGeaBFYHehqr8yISWf
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman, Patrick Brisbin
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Authentication for Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-auth>
category: Web, Yesod
abi: 29676a73d93e12f0944a162180242ea1
exposed: True
exposed-modules:
    Yesod.Auth Yesod.Auth.BrowserId Yesod.Auth.Dummy Yesod.Auth.Email
    Yesod.Auth.GoogleEmail2 Yesod.Auth.Hardcoded Yesod.Auth.Message
    Yesod.Auth.OpenId Yesod.Auth.Rpxnow Yesod.Auth.Util.PasswordStore
hidden-modules: Yesod.Auth.Routes
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-auth-1.6.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-auth-1.6.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-auth-1.6.7
hs-libraries: HSyesod-auth-1.6.7-4gBMbGeaBFYHehqr8yISWf
depends:
    aeson-1.4.4.0-7vLg8fT3jLZEAAmFwxYKHF
    authenticate-1.3.4-2eX9Gs8svuw2zndifA5Ox2 base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    base64-bytestring-1.0.0.2-4mGTJNwsUu7LJDOWBfkS70 binary-0.8.6.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-html-0.9.1.1-JqQvdi8Kk8N7YPtWE4umgt
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    conduit-1.3.1.1-JSdi7R8L6wUIGZiBi8qKpO
    conduit-extra-1.3.2-D50RCH6hLiF4M9x0U29P7E containers-0.6.0.1
    cryptonite-0.26-5pCtI3fv84M4lNt7lObUcf
    data-default-0.7.1.1-GQk9Hqcpzml6dpaWfistUm
    email-validate-2.3.2.11-BqDvj9YDc46Ire3mRLLi3C
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
    http-client-0.6.4-2vvZT4nV8ZwJDNuwGeFyhx
    http-client-tls-0.3.5.3-Au4LL1tAcd0ClbEGyFVtJV
    http-conduit-2.3.7.1-2QrTCTUeO2R1ar6JmbSyHS
    http-types-0.12.3-BsfSThCiYntF94Mfs0JU92
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    nonce-1.0.7-LK0kbFjana5L4E7V8wfmpA
    persistent-2.9.2-3u8mTjXoGWf7WTPndodnQb
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    shakespeare-2.0.20-7fMjMkQ4P2XAjVbJqYEYiv template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    unliftio-0.2.11-Ji7KANMHEQS2vCzP6xKQkx
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-1qvqZt81kSY49gkPLj6it0
    wai-3.2.2.1-FDNwy6o9t7ZJaaGowNIQmS
    yesod-core-1.6.14-BpSYxRxJq3Y4APvNlRsunx
    yesod-form-1.6.5-3jvdG0NL6j61FrIzIGsTfQ
    yesod-persistent-1.6.0.2-xGbiKW6Z6IUfD35WYUqj
haddock-interfaces: /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
haddock-html: /usr/share/doc/haskell-yesod-auth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
